<?php
// $Id: php_errors_actions.inc,v 1.2 2008/05/27 02:34:46 ptalindstrom Exp $   
                               
define ('ONEYEAR', 3600*24*365);
define ('ONEWEEK', 3600*24*7);
define ('ONEDAY', 3600*24);
  
// make sure that our precanned actions exist
$precanned = db_result(db_query("SELECT aid FROM {actions} WHERE func = '%s'", 'action_php_errors_notify'));
if (!$precanned) _php_errors_create_precanned_actions(); 

  
/**
 * Define email action to send Quarterly email notification to all users in Country role.
*/

function action_php_errors_notify($op, $edit = array(), $node) {
  global $variables;
  
  switch ($op) {
    case 'metadata':
      return array(
        'description'  => t("PHP Errors: Send weekly PHP Error report."),
        'type'         => t('Email'),
        'batchable'    => false,
        'configurable' => TRUE,
      );
    
    case 'do':
      // pull list of all user in selected roles
      $users = _php_errors_get_roles_emails();
      
      // and add individual csv list of addresses
      $single_emails = split(",", variable_get('php_errors_notify_addresses', variable_get('site_mail', '')));
      foreach ($single_emails as $single) $users[trim($single)] = trim($single);
      
      $users = array_unique($users);
      
      $site_name = variable_get('site_name', 'Drupal');
      $from = "$site_name <". variable_get('site_mail', ini_get('sendmail_from')) .'>';
      $subject = module_invoke('token', 'replace', $edit['subject'], 'node', $node);
      $message = module_invoke('token', 'replace', $edit['message'], 'node', $node);
      
      // add this weeks report to the email message
      $message .= _php_errors_show();
      
      foreach ($users as $name => $email) {  
        $message = str_replace('[username]', $name, $message); 
        if (!drupal_mail('php_errors_notify', $email, $subject, $message, $from)) {
          watchdog('php errors', t('Unable to send email to %user <%email>',
            array('%user' => $name, '%email' => $email)), WATCHDOG_ERROR);
        }
      }
      watchdog('php errors', t("Weekly PHP Error summary report sent out."), WATCHDOG_NOTICE);
      break;

    // return an HTML config form for the action
    case 'form':
      $form = array();
      $form['subject'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Subject'),
        '#required'      => TRUE,
        '#default_value' => $edit['subject'],
        '#size'          => '80',
        '#maxlength'     => '254',
        '#description' => t('The subject of the email message. You may include "tokens" in this field which will be replaced with their actual
          values. Useful tokens include: [nid], [body], [teaser], [title], [url], [site-name]. This list is not comprehensive.'),
      );
      $form['message'] = array(
        '#type'          => 'textarea',
        '#title'         => t('Message'),
        '#required'      => TRUE,
        '#default_value' => $edit['message'],
        '#cols'          => '80',
        '#rows'          => '20',
        '#description' => t('The body of the email message. You may include "tokens" in this field which will be replaced with their actual
          values. Useful tokens include: [username], [nid], [body], [teaser], [title], [url], [site-name]. This list is not comprehensive.'),
      );

      return $form;

    // validate the HTML form
    case 'validate':
      return TRUE;

    // process the HTML form to store configuration
    case 'submit':
      $params = array(
        'subject'    => $edit['subject'],
        'message'    => $edit['message'],
      );

      return $params;
  }
} 

// get array of all email addresses for each user in selected roles
function _php_errors_get_roles_emails() {
  $emails = array();
  
  $roles = variable_get('php_errors_notify_roles', 0);
  if (!$roles) return;
  
  $included = array_filter($roles);
  
  if (count($included) > 1) {
    foreach ($included as $role) $rolesql[] = " ur.rid = $role ";
    $roles_where = join(" OR ", $rolesql);
  }
  else $roles_where = " ur.rid = ". $included[0]; 
  
  $result = db_query("SELECT u.uid, u.name, u.mail, u.status FROM {users} u
    INNER JOIN {users_roles} ur ON u.uid=ur.uid WHERE $roles_where AND u.status = 1");
  
  while ($u = db_fetch_object($result)) $emails[$u->name] = $u->mail;
  
  return $emails;
}

// creates precanned action to send email notification to submitter
//  - gets called during module install
//  - but in case it gets deleted we also check if action exists, and if not also create there  
function _php_errors_create_precanned_actions() {     
    $function = "action_php_errors_notify";
    $type = "Email";
    $params = array(
      'subject' => "PHP Error Summary Report.",
      'message' => "The following is this weeks PHP Error Summary Report.\n\r\n\rRegards,\n[site-name]"
    );
    $desc = t("PHP Errors: Send weekly PHP Error report.");
    actions_save($function, $type, $params, $desc);
}          
